summaryrefslogtreecommitdiff
path: root/xmake/core/base/global.lua
diff options
context:
space:
mode:
authorruki <[email protected]>2016-02-28 14:14:25 +0800
committerruki <[email protected]>2016-02-28 14:14:25 +0800
commit5c154ce0b281f073fb6c8e475e932837da0d5117 (patch)
treeb670dfe584762f397fe466be227b09d375b1ec90 /xmake/core/base/global.lua
parent9212146ac3d022a54f659d87fb0ecd7a7db2bee4 (diff)
hide _OPTIONS
Diffstat (limited to 'xmake/core/base/global.lua')
-rw-r--r--xmake/core/base/global.lua6
1 files changed, 3 insertions, 3 deletions
diff --git a/xmake/core/base/global.lua b/xmake/core/base/global.lua
index a3d06acda..2c178af71 100644
--- a/xmake/core/base/global.lua
+++ b/xmake/core/base/global.lua
@@ -37,7 +37,7 @@ function global._make()
assert(configs)
-- the options
- local options = xmake._OPTIONS
+ local options = option.options()
assert(options)
-- init current global configure
@@ -125,7 +125,7 @@ end
function global.load()
-- the options
- local options = xmake._OPTIONS
+ local options = option.options()
assert(options)
-- check
@@ -171,7 +171,7 @@ function global.load()
-- xmake global?
if options._TASK == "global" then
- -- merge xmake._OPTIONS to the global configure
+ -- merge option.options() to the global configure
for k, v in pairs(options) do
-- check